# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='request.proto',
  package='request',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rrequest.proto\x12\x07request\x1a\x1bgoogle/protobuf/empty.proto\"\x8c\x02\n\x0e\x43omputeRequest\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61\x63hed\x18\x03 \x01(\x08\x12\x0f\n\x07package\x18\x04 \x01(\x0c\x12\x13\n\x0b\x62inary_path\x18\x05 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x06 \x03(\t\x12\x0c\n\x04\x65nvs\x18\x07 \x03(\t\x12\x0e\n\x06params\x18\x08 \x01(\t\x12\x0f\n\x07returns\x18\t \x01(\t\x12\x14\n\x0cnetwork_perm\x18\n \x03(\t\x12\x15\n\rtriggered_tag\x18\x0b \x01(\t\x12\x1b\n\x13triggered_timestamp\x18\x0c \x01(\t\x12\x16\n\x0etriggered_data\x18\r \x01(\x0c\"$\n\x0bNotifyStart\x12\x15\n\rprocess_token\x18\x01 \x01(\t\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x90\x01\n\rNetworkAccess\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x15\n\rprocess_token\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0e\n\x06method\x18\x04 \x01(\t\x12&\n\x07headers\x18\x05 \x03(\x0b\x32\x15.request.KeyValuePair\x12\x0c\n\x04\x62ody\x18\x06 \x01(\x0c\"`\n\x13NetworkAccessResult\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\x07headers\x18\x02 \x03(\x0b\x32\x15.request.KeyValuePair\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"_\n\x07GetData\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x15\n\rprocess_token\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05lower\x18\x04 \x01(\t\x12\r\n\x05upper\x18\x05 \x01(\t\"1\n\rGetDataResult\x12\x12\n\ntimestamps\x18\x01 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x0c\"P\n\x08PushData\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x15\n\rprocess_token\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\'\n\x0fStateChangeInit\x12\x14\n\x0csensor_token\x18\x01 \x01(\t\"-\n\x0fStateChangePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"g\n\x0bStateChange\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x15\n\rprocess_token\x18\x02 \x01(\t\x12\x11\n\tsensor_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x0c\"R\n\x13HostRegisterRequest\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08password\x18\x04 \x01(\t\"(\n\x12HostRegisterResult\x12\x12\n\nhost_token\x18\x01 \x01(\t\"6\n\tNotifyEnd\x12\x12\n\nhost_token\x18\x01 \x01(\t\x12\x15\n\rprocess_token\x18\x02 \x01(\t\"#\n\rHostHeartbeat\x12\x12\n\nhost_token\x18\x01 \x01(\t\"]\n\x15SensorRegisterRequest\x12\x18\n\x10global_sensor_id\x18\x01 \x01(\t\x12\x0b\n\x03\x61pp\x18\x02 \x01(\x0c\x12\x0f\n\x07returns\x18\x03 \x03(\t\x12\x0c\n\x04keys\x18\x04 \x03(\t\"?\n\x14SensorRegisterResult\x12\x14\n\x0csensor_token\x18\x01 \x01(\t\x12\x11\n\tsensor_id\x18\x02 \x01(\t\"C\n\x0eSensorPushData\x12\x14\n\x0csensor_token\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x32\xee\x01\n\x08KarlHost\x12=\n\x0cStartCompute\x12\x17.request.ComputeRequest\x1a\x14.request.NotifyStart\x12?\n\x07Network\x12\x16.request.NetworkAccess\x1a\x1c.request.NetworkAccessResult\x12/\n\x03Get\x12\x10.request.GetData\x1a\x16.request.GetDataResult\x12\x31\n\x04Push\x12\x11.request.PushData\x1a\x16.google.protobuf.Empty2\x9e\x05\n\x0eKarlController\x12I\n\x0cHostRegister\x12\x1c.request.HostRegisterRequest\x1a\x1b.request.HostRegisterResult\x12@\n\x0e\x46orwardNetwork\x12\x16.request.NetworkAccess\x1a\x16.google.protobuf.Empty\x12\x36\n\nForwardGet\x12\x10.request.GetData\x1a\x16.request.GetDataResult\x12\x38\n\x0b\x46orwardPush\x12\x11.request.PushData\x1a\x16.google.protobuf.Empty\x12<\n\x0c\x46orwardState\x12\x14.request.StateChange\x1a\x16.google.protobuf.Empty\x12;\n\rFinishCompute\x12\x12.request.NotifyEnd\x1a\x16.google.protobuf.Empty\x12;\n\tHeartbeat\x12\x16.request.HostHeartbeat\x1a\x16.google.protobuf.Empty\x12O\n\x0eSensorRegister\x12\x1e.request.SensorRegisterRequest\x1a\x1d.request.SensorRegisterResult\x12>\n\x0bPushRawData\x12\x17.request.SensorPushData\x1a\x16.google.protobuf.Empty\x12\x44\n\x0cStateChanges\x12\x18.request.StateChangeInit\x1a\x18.request.StateChangePair0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_COMPUTEREQUEST = _descriptor.Descriptor(
  name='ComputeRequest',
  full_name='request.ComputeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.ComputeRequest.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_id', full_name='request.ComputeRequest.module_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cached', full_name='request.ComputeRequest.cached', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='request.ComputeRequest.package', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_path', full_name='request.ComputeRequest.binary_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='request.ComputeRequest.args', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='envs', full_name='request.ComputeRequest.envs', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='request.ComputeRequest.params', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='returns', full_name='request.ComputeRequest.returns', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_perm', full_name='request.ComputeRequest.network_perm', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggered_tag', full_name='request.ComputeRequest.triggered_tag', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggered_timestamp', full_name='request.ComputeRequest.triggered_timestamp', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggered_data', full_name='request.ComputeRequest.triggered_data', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=324,
)


_NOTIFYSTART = _descriptor.Descriptor(
  name='NotifyStart',
  full_name='request.NotifyStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.NotifyStart.process_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=362,
)


_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='request.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='request.KeyValuePair.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='request.KeyValuePair.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=406,
)


_NETWORKACCESS = _descriptor.Descriptor(
  name='NetworkAccess',
  full_name='request.NetworkAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.NetworkAccess.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.NetworkAccess.process_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='request.NetworkAccess.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='request.NetworkAccess.method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='request.NetworkAccess.headers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='request.NetworkAccess.body', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=553,
)


_NETWORKACCESSRESULT = _descriptor.Descriptor(
  name='NetworkAccessResult',
  full_name='request.NetworkAccessResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='request.NetworkAccessResult.status_code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='request.NetworkAccessResult.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='request.NetworkAccessResult.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=651,
)


_GETDATA = _descriptor.Descriptor(
  name='GetData',
  full_name='request.GetData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.GetData.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.GetData.process_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='request.GetData.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower', full_name='request.GetData.lower', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='request.GetData.upper', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=748,
)


_GETDATARESULT = _descriptor.Descriptor(
  name='GetDataResult',
  full_name='request.GetDataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='request.GetDataResult.timestamps', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='request.GetDataResult.data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=799,
)


_PUSHDATA = _descriptor.Descriptor(
  name='PushData',
  full_name='request.PushData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.PushData.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.PushData.process_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='request.PushData.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='request.PushData.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=881,
)


_STATECHANGEINIT = _descriptor.Descriptor(
  name='StateChangeInit',
  full_name='request.StateChangeInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_token', full_name='request.StateChangeInit.sensor_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=922,
)


_STATECHANGEPAIR = _descriptor.Descriptor(
  name='StateChangePair',
  full_name='request.StateChangePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='request.StateChangePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='request.StateChangePair.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=969,
)


_STATECHANGE = _descriptor.Descriptor(
  name='StateChange',
  full_name='request.StateChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.StateChange.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.StateChange.process_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_id', full_name='request.StateChange.sensor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='request.StateChange.key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='request.StateChange.value', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1074,
)


_HOSTREGISTERREQUEST = _descriptor.Descriptor(
  name='HostRegisterRequest',
  full_name='request.HostRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_id', full_name='request.HostRegisterRequest.host_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='request.HostRegisterRequest.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='request.HostRegisterRequest.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='request.HostRegisterRequest.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1076,
  serialized_end=1158,
)


_HOSTREGISTERRESULT = _descriptor.Descriptor(
  name='HostRegisterResult',
  full_name='request.HostRegisterResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.HostRegisterResult.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1200,
)


_NOTIFYEND = _descriptor.Descriptor(
  name='NotifyEnd',
  full_name='request.NotifyEnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.NotifyEnd.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_token', full_name='request.NotifyEnd.process_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1256,
)


_HOSTHEARTBEAT = _descriptor.Descriptor(
  name='HostHeartbeat',
  full_name='request.HostHeartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_token', full_name='request.HostHeartbeat.host_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1258,
  serialized_end=1293,
)


_SENSORREGISTERREQUEST = _descriptor.Descriptor(
  name='SensorRegisterRequest',
  full_name='request.SensorRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='global_sensor_id', full_name='request.SensorRegisterRequest.global_sensor_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app', full_name='request.SensorRegisterRequest.app', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='returns', full_name='request.SensorRegisterRequest.returns', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys', full_name='request.SensorRegisterRequest.keys', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1388,
)


_SENSORREGISTERRESULT = _descriptor.Descriptor(
  name='SensorRegisterResult',
  full_name='request.SensorRegisterResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_token', full_name='request.SensorRegisterResult.sensor_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_id', full_name='request.SensorRegisterResult.sensor_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1453,
)


_SENSORPUSHDATA = _descriptor.Descriptor(
  name='SensorPushData',
  full_name='request.SensorPushData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_token', full_name='request.SensorPushData.sensor_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param', full_name='request.SensorPushData.param', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='request.SensorPushData.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1455,
  serialized_end=1522,
)

_NETWORKACCESS.fields_by_name['headers'].message_type = _KEYVALUEPAIR
_NETWORKACCESSRESULT.fields_by_name['headers'].message_type = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['ComputeRequest'] = _COMPUTEREQUEST
DESCRIPTOR.message_types_by_name['NotifyStart'] = _NOTIFYSTART
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['NetworkAccess'] = _NETWORKACCESS
DESCRIPTOR.message_types_by_name['NetworkAccessResult'] = _NETWORKACCESSRESULT
DESCRIPTOR.message_types_by_name['GetData'] = _GETDATA
DESCRIPTOR.message_types_by_name['GetDataResult'] = _GETDATARESULT
DESCRIPTOR.message_types_by_name['PushData'] = _PUSHDATA
DESCRIPTOR.message_types_by_name['StateChangeInit'] = _STATECHANGEINIT
DESCRIPTOR.message_types_by_name['StateChangePair'] = _STATECHANGEPAIR
DESCRIPTOR.message_types_by_name['StateChange'] = _STATECHANGE
DESCRIPTOR.message_types_by_name['HostRegisterRequest'] = _HOSTREGISTERREQUEST
DESCRIPTOR.message_types_by_name['HostRegisterResult'] = _HOSTREGISTERRESULT
DESCRIPTOR.message_types_by_name['NotifyEnd'] = _NOTIFYEND
DESCRIPTOR.message_types_by_name['HostHeartbeat'] = _HOSTHEARTBEAT
DESCRIPTOR.message_types_by_name['SensorRegisterRequest'] = _SENSORREGISTERREQUEST
DESCRIPTOR.message_types_by_name['SensorRegisterResult'] = _SENSORREGISTERRESULT
DESCRIPTOR.message_types_by_name['SensorPushData'] = _SENSORPUSHDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComputeRequest = _reflection.GeneratedProtocolMessageType('ComputeRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTEREQUEST,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.ComputeRequest)
  })
_sym_db.RegisterMessage(ComputeRequest)

NotifyStart = _reflection.GeneratedProtocolMessageType('NotifyStart', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYSTART,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.NotifyStart)
  })
_sym_db.RegisterMessage(NotifyStart)

KeyValuePair = _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEPAIR,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.KeyValuePair)
  })
_sym_db.RegisterMessage(KeyValuePair)

NetworkAccess = _reflection.GeneratedProtocolMessageType('NetworkAccess', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKACCESS,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.NetworkAccess)
  })
_sym_db.RegisterMessage(NetworkAccess)

NetworkAccessResult = _reflection.GeneratedProtocolMessageType('NetworkAccessResult', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKACCESSRESULT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.NetworkAccessResult)
  })
_sym_db.RegisterMessage(NetworkAccessResult)

GetData = _reflection.GeneratedProtocolMessageType('GetData', (_message.Message,), {
  'DESCRIPTOR' : _GETDATA,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.GetData)
  })
_sym_db.RegisterMessage(GetData)

GetDataResult = _reflection.GeneratedProtocolMessageType('GetDataResult', (_message.Message,), {
  'DESCRIPTOR' : _GETDATARESULT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.GetDataResult)
  })
_sym_db.RegisterMessage(GetDataResult)

PushData = _reflection.GeneratedProtocolMessageType('PushData', (_message.Message,), {
  'DESCRIPTOR' : _PUSHDATA,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.PushData)
  })
_sym_db.RegisterMessage(PushData)

StateChangeInit = _reflection.GeneratedProtocolMessageType('StateChangeInit', (_message.Message,), {
  'DESCRIPTOR' : _STATECHANGEINIT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.StateChangeInit)
  })
_sym_db.RegisterMessage(StateChangeInit)

StateChangePair = _reflection.GeneratedProtocolMessageType('StateChangePair', (_message.Message,), {
  'DESCRIPTOR' : _STATECHANGEPAIR,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.StateChangePair)
  })
_sym_db.RegisterMessage(StateChangePair)

StateChange = _reflection.GeneratedProtocolMessageType('StateChange', (_message.Message,), {
  'DESCRIPTOR' : _STATECHANGE,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.StateChange)
  })
_sym_db.RegisterMessage(StateChange)

HostRegisterRequest = _reflection.GeneratedProtocolMessageType('HostRegisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREGISTERREQUEST,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.HostRegisterRequest)
  })
_sym_db.RegisterMessage(HostRegisterRequest)

HostRegisterResult = _reflection.GeneratedProtocolMessageType('HostRegisterResult', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREGISTERRESULT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.HostRegisterResult)
  })
_sym_db.RegisterMessage(HostRegisterResult)

NotifyEnd = _reflection.GeneratedProtocolMessageType('NotifyEnd', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYEND,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.NotifyEnd)
  })
_sym_db.RegisterMessage(NotifyEnd)

HostHeartbeat = _reflection.GeneratedProtocolMessageType('HostHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _HOSTHEARTBEAT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.HostHeartbeat)
  })
_sym_db.RegisterMessage(HostHeartbeat)

SensorRegisterRequest = _reflection.GeneratedProtocolMessageType('SensorRegisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORREGISTERREQUEST,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.SensorRegisterRequest)
  })
_sym_db.RegisterMessage(SensorRegisterRequest)

SensorRegisterResult = _reflection.GeneratedProtocolMessageType('SensorRegisterResult', (_message.Message,), {
  'DESCRIPTOR' : _SENSORREGISTERRESULT,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.SensorRegisterResult)
  })
_sym_db.RegisterMessage(SensorRegisterResult)

SensorPushData = _reflection.GeneratedProtocolMessageType('SensorPushData', (_message.Message,), {
  'DESCRIPTOR' : _SENSORPUSHDATA,
  '__module__' : 'request_pb2'
  # @@protoc_insertion_point(class_scope:request.SensorPushData)
  })
_sym_db.RegisterMessage(SensorPushData)



_KARLHOST = _descriptor.ServiceDescriptor(
  name='KarlHost',
  full_name='request.KarlHost',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1525,
  serialized_end=1763,
  methods=[
  _descriptor.MethodDescriptor(
    name='StartCompute',
    full_name='request.KarlHost.StartCompute',
    index=0,
    containing_service=None,
    input_type=_COMPUTEREQUEST,
    output_type=_NOTIFYSTART,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Network',
    full_name='request.KarlHost.Network',
    index=1,
    containing_service=None,
    input_type=_NETWORKACCESS,
    output_type=_NETWORKACCESSRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='request.KarlHost.Get',
    index=2,
    containing_service=None,
    input_type=_GETDATA,
    output_type=_GETDATARESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Push',
    full_name='request.KarlHost.Push',
    index=3,
    containing_service=None,
    input_type=_PUSHDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KARLHOST)

DESCRIPTOR.services_by_name['KarlHost'] = _KARLHOST


_KARLCONTROLLER = _descriptor.ServiceDescriptor(
  name='KarlController',
  full_name='request.KarlController',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1766,
  serialized_end=2436,
  methods=[
  _descriptor.MethodDescriptor(
    name='HostRegister',
    full_name='request.KarlController.HostRegister',
    index=0,
    containing_service=None,
    input_type=_HOSTREGISTERREQUEST,
    output_type=_HOSTREGISTERRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForwardNetwork',
    full_name='request.KarlController.ForwardNetwork',
    index=1,
    containing_service=None,
    input_type=_NETWORKACCESS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForwardGet',
    full_name='request.KarlController.ForwardGet',
    index=2,
    containing_service=None,
    input_type=_GETDATA,
    output_type=_GETDATARESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForwardPush',
    full_name='request.KarlController.ForwardPush',
    index=3,
    containing_service=None,
    input_type=_PUSHDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForwardState',
    full_name='request.KarlController.ForwardState',
    index=4,
    containing_service=None,
    input_type=_STATECHANGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishCompute',
    full_name='request.KarlController.FinishCompute',
    index=5,
    containing_service=None,
    input_type=_NOTIFYEND,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Heartbeat',
    full_name='request.KarlController.Heartbeat',
    index=6,
    containing_service=None,
    input_type=_HOSTHEARTBEAT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SensorRegister',
    full_name='request.KarlController.SensorRegister',
    index=7,
    containing_service=None,
    input_type=_SENSORREGISTERREQUEST,
    output_type=_SENSORREGISTERRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PushRawData',
    full_name='request.KarlController.PushRawData',
    index=8,
    containing_service=None,
    input_type=_SENSORPUSHDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StateChanges',
    full_name='request.KarlController.StateChanges',
    index=9,
    containing_service=None,
    input_type=_STATECHANGEINIT,
    output_type=_STATECHANGEPAIR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KARLCONTROLLER)

DESCRIPTOR.services_by_name['KarlController'] = _KARLCONTROLLER

# @@protoc_insertion_point(module_scope)
